Functions
- fetch_
supported_ collections - Fetch the catalog’s
/collectionsendpoint and return the set of canonical collection IDs it supports, after reversing any configured alias map (catalog-local -> canonical). TODO - What if collection is over 100, do I need to add a limit param and loop with pagination?